#
# spec file for package uki-tool
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define archive_name unified-kernel-image-tool
%define bin_name uki-tool

Name:           uki-tool
Version:        1.4.1+0.g2720d37
Release:        1.1
Summary:        Tool for the UKI and static-initrd project
License:        MIT
URL:            https://github.com/keentux/unified-kernel-image-tool.git
Source:         %{archive_name}-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  ShellCheck
BuildRequires:  bash-sh
BuildRequires:  coreutils
Requires:       awk
Requires:       bash-sh
Requires:       bind-utils
Requires:       binutils
Requires:       coreutils
Requires:       e2fsprogs
Requires:       rpm
Requires:       squashfs
# Require to have lsinitrd
Requires:       dracut

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tool that regroups useful command dealing with the Unified Kernel Image (UKI)
and static-initrd project. Write in Shell script, and adapted for the packaging.

%package doc
Summary:        Documentation for the package uki-tool
Group:          Documentation/Man
BuildRequires:  gzip
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
This package contains the documentation for the uki-tool.

%prep
%autosetup -n %{archive_name}-%{version}

%build
sh ./build.sh

%install
sh ./install.sh \
    --prefix "%{buildroot}"\
    --bindir="%{_bindir}"\
    --mandir="%{_mandir}"

%files
%defattr(-,root,root)
%{_bindir}/%{bin_name}

%files doc
%doc README.md LICENSE AUTHORS CHANGELOG.md
%{_mandir}/man1/%{bin_name}.1%{?ext_man}

%changelog
* Mon Dec 16 2024 valentin.lefebvre@suse.com
- Update to version 1.4.1+0.g2720d37:
  * Release to 1.4.1
  * bootloaders: remove installed uki
  * bootloaders: all-ukis option
  * COMMON_KERNEL_MODULESDIR variable
* Mon Sep  9 2024 valentin.lefebvre@suse.com
- Update to version 1.4.0+0.g50e5885:
  * Release 1.4.0
  * grub2 removing entry: use entry ID
  * grub2 removing entry: check if menuentry discovered
  * common format uki: check if not already formated
  * uki installation: Fromat the efi filename in the efi partition
  * sdboot default: call bootctl set-default
  * grub2: remove uki with id name
  * bootloader: Add cmdline options
  * bootloader: Add title option for entries
  * helper: fix usage output when unknown command
  * sdboot_initrd: remove the installed intird
  * sdboot_initrd: update doc and man
  * sdboot: add static initrd option
  * grub2_initrd: Add the default option
  * grub2_initrd: fix root uuid discovering
* Fri Aug  2 2024 valentin.lefebvre@suse.com
- Update to version 1.3.0+0.g23696fa:
  * Release to 1.3.0
  * sdboot:
  * add new paramters to choose in which efi directory deals
  * default one is "/EFI/Linux" but could be "/EFI/opensuse"
  * parameter should be "kerver" instead of "kernel"
  * Format build and install script
  * binary name from `ukit` to `uki-tool`
  * extension:
  * Generate dedicated extensions with size optimisation
  * Move device functions into common
  * common_get_dev
  * Create a common function to install uki into efi dir
  * sdboot paramter
  * BEAK RETRO-COMPATIBILITY
  * from "image" to "uki"
  * sdboot indepependant of sdbootutil
  * Until uki feature is implemented into this tool, it uses now bootctl
    command and basic configuration files.
  * Improve how entry are added/removed for sdboot and grub
  * Create the UKI in case of missing installation.
  * common: prefer verify "/boot/efi" to know if efi is in used.
* Fri Jul  5 2024 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Change package name from ukit to uki-tool
* Mon May 27 2024 valentin.lefebvre@suse.com
- Remove upstream fixed patch
  [- remove-snapshot-number-condition.patch]
- Update to version 1.2.0+0.g87efdd2:
  * Release to 1.2.0
  * doc: add manual
  * install.sh: Add prefix argument
  * extension: add no-deps option
  * Add specfile + update changelog
  * src: move src files
  * snapper: add plugin to snapper
  * addon: Removing snapshot number condition
  * Update to release 1.1.0
* Wed Apr 24 2024 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Patch the addon command to accept non numbered snapshot
  [+ remove-snapshot-number-condition.patch]
* Fri Apr 19 2024 valentin.lefebvre@suse.com
- Update to version 1.0.0+8.geb71bab:
  * addon: argument to create snpashot
  * create: fix calling the helper if wrong argument
  * addon: add command to generate addons
  * ukify: export the binary path
  * build.sh: check if all functions are defined
  * build.sh: Remove export
* Mon Mar 11 2024 valentin.lefebvre@suse.com
- Moving srouces to github
- Add AUTHORS and Changelog files in doc
- Update to version 1.0.0+2.g1c51d7e:
  * sdboot: Add ach argument
  * license: swith to MIT license
  * Release to 1.0.0
  * Inform about tools to use in doc
  * add AUTHORS file
* Mon Mar  4 2024 valentin.lefebvre@suse.com
- Update to version 0.3.0+15.g1de0ad2:
  * sdboot: Add doc to readme
  * Contributing file
  * Readme: Add new command and fix descr
  * create command: generate UKI
  * helpers: use 'OPTIONS' for usage print
  * Export usefull varaibles
* Fri Mar  1 2024 valentin.lefebvre@suse.com
- Update to version 0.3.0+9.gba4e135:
  * sdboot: use image option of sdbootutil
* Thu Feb 29 2024 valentin.lefebvre@suse.com
- Update to version 0.3.0+8.ga51b691:
  * helper: improve messages
  * sdboot: Add command to add/remove entry
* Mon Oct 23 2023 valentin.lefebvre@suse.com
- Update to version 0.3.0+6:
  * grub2: verify available memory in efi part
* Mon Oct 23 2023 valentin.lefebvre@suse.com
- Update to version 0.3.0+5:
  * grub2: fix: UUID device & transactional
* Thu Oct 19 2023 valentin.lefebvre@suse.com
- Update to version v0.3.0+4:
  * grub2: create dir in efi part
  * print correct helper & check grub2 file
  * grub2: fix variable condition
  * Add changelog file
* Mon Oct  9 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Remove grub2 requires. Can be used with sdboot (conflicting)
* Mon Sep 25 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Fix grub2 condition variable
  [0001-grub2-fix-variable-condition.patch]
* Mon Sep 25 2023 valentin.lefebvre@suse.com
- Update to version 0.3.0:
  * Add installation script
  * Switch from bash to shell with shellcheck
  * readme: update to 0.2.1
  * extension: add default format squashfs
  * grub2: check kernel version only when add initrd
  * readme: add commands documentation
  * command: add grub2 commands
  * extension: Update the uki installation path
  * build.sh: Identicate lines with #!
  * extension: optimize image creation
- Update installation on Specfile
* Wed Jul 12 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Add requires to squashfs
* Wed Jul 12 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Update to 0.2.1
  * Add extension format squashfs
- specfile
  * Use the archive name given by the git project
* Tue Jun  6 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Add patch 0001-grub2-check-kernel-version-only-when-add-initrd.patch
* Tue Jun  6 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Update to version 0.2.0
  * Add grub2 command
  * Update documentation
  * Update uki installation path
  * Fix the line parser in build
* Tue May  9 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Switch requires from osc to zypper
* Fri May  5 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- version 0.1
